==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/es_AR.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Contraseña de llave de recuperacion faltante",
    "Please repeat the recovery key password" : "Favor de reingresar la contraseña de recuperación",
    "Repeated recovery key password does not match the provided recovery key password" : "Las contraseñas de la llave de recuperación no coinciden",
    "Recovery key successfully enabled" : "Llave de recuperación habilitada exitosamente",
    "Could not enable recovery key. Please check your recovery key password!" : "No fue posible habilitar la llave de recuperación. ¡Favor de comprobar la contraseña de su llave de recuperación!",
    "Recovery key successfully disabled" : "Llave de recuperación deshabilitada exitosamente",
    "Could not disable recovery key. Please check your recovery key password!" : "No fue posible deshabilitar la llave de recuperación. ¡Favor de comprobar la contraseña de la llave de recuperación!",
    "Missing parameters" : "Parámetros faltantes",
    "Please provide the old recovery password" : "Favor de proporcionar su contraseña de recuperación anterior",
    "Please provide a new recovery password" : "Favor de proporcionar una nueva contraseña de recuperación",
    "Please repeat the new recovery password" : "Favor de reingresar la nueva contraseña de recuperación",
    "Password successfully changed." : "La contraseña ha sido cambiada exitosamente",
    "Could not change the password. Maybe the old password was not correct." : "No fue posible cambiar la contraseña. Favor de verificar que contraseña anterior sea correcta.",
    "Recovery Key disabled" : "Llave de recuperación deshabilitada",
    "Recovery Key enabled" : "Llave de recuperación habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "No fue posible habilitar la llave de recuperación, favor de intentarlo de nuevo o contacte a su administrador",
    "Could not update the private key password." : "No fue posible actualizar la contraseña de la llave privada.",
    "The old password was not correct, please try again." : "La contraseña anterior no es correcta, favor de intentar de nuevo. ",
    "The current log-in password was not correct, please try again." : "La contraseña actual para iniciar sesión fue incorrecta, favor de volverlo a intentar. ",
    "Private key password successfully updated." : "Contraseña de llave privada actualizada exitosamente.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Usted necesita migrar sus llaves de la encripción anterior (ownCloud <=8.0) a la nueva. Favor de ejecutar 'occ encryption:migrate' o contacte a su adminstrador",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "La llave de encriptación privada es inválida para la aplicación de encriptación. Favor de actualizar la contraseña de su llave privada en sus configuraciones personales para recuperar el acceso a sus archivos encriptados. ",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "La aplicación de encripción está habilitada, pero sus llaves no han sido inicializadas. Favor de cerrar sesión e iniciar sesión de nuevo. ",
    "Encryption app is enabled and ready" : "La aplicación de encripción se cuentra habilitada y lista",
    "Bad Signature" : "Firma equivocada",
    "Missing Signature" : "Firma faltante",
    "one-time password for server-side-encryption" : "Contraseña de una-sola-vez para la encripción del lado del servidor",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es posible decriptar este archivo, posiblemente sea un archivo compartido. Favor de solicitar al dueño del archivo que lo vuelva a compartir con usted.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es posible leer este archivo, posiblemente sea un archivo compatido. Favor de solicitar al dueño que vuelva a compartirlo con usted. ",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hola,\n\nel administrador ha habilitado la encripción de lado del servidor. Sus archivos fueron encriptados usando la contraseña '%s'\n\nFavor de iniciar sesión en la interface web, vaya a la sección \"módulo de encripción básica\" de sus configuraciones personales y actualice su contraseña de encripción ingresando esta contraseña en el campo 'contraseña de inicio de sesión anterior' y su contraseña de inicio de sesión actual. \n",
    "The share will expire on %s." : "El elemento compartido expirará el %s.",
    "Cheers!" : "¡Saludos!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hola, <br><br>el administrador ha habilitado la encripción del lado del servidor. Sus archivos fueron encriptados usando la contraseña <strong>%s</strong>.<br><br> Favor de iniciar sesisón en la interface web, vaya a la sección \"módulo de encripción básica\" de sus configuraciones personales y actualice su contraseña de encripción ingresando esta contraseña en el campo \"contraseña de inicio de sesión anterior\" y su contraseña de inicio de sesión actual. <br><br>",
    "Default encryption module" : "Módulo de encripción predeterminado",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "La aplicación de encripción esta habilitada pero sus llaves no han sido inicializadas, favor de salir y volver a entrar a la sesion",
    "Encrypt the home storage" : "Encriptar el almacenamiento de inicio",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Habilitar esta opción encripta todos los archivos almacenados en el almacenamiento principal, de otro modo, sólo los archivos en el almacenamiento externo serán encriptados",
    "Enable recovery key" : "Habilitar llave de recuperación",
    "Disable recovery key" : "Deshabilitar llave de recuperación",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "La llave de recuperación es una llave de encripción que se usa para encriptar archivos. Permite la recuperación de los archivos del usuario si este olvida su contraseña. ",
    "Recovery key password" : "Contraseña de llave de recuperación",
    "Repeat recovery key password" : "Repetir la contraseña de la llave de recuperación",
    "Change recovery key password:" : "Cambiar la contraseña de la llave de recuperación:",
    "Old recovery key password" : "Anterior contraseña de llave de recuperación",
    "New recovery key password" : "Nueva contraseña de llave de recuperación",
    "Repeat new recovery key password" : "Reingresar la nueva contraseña de llave de recuperación",
    "Change Password" : "Cambiar contraseña",
    "Basic encryption module" : "Módulo de encripción básica",
    "Your private key password no longer matches your log-in password." : "Su contraseña de llave privada ya no corresónde con su contraseña de inicio de sesión. ",
    "Set your old private key password to your current log-in password:" : "Establezca su contraseña de llave privada a su contraseña actual de inicio de seisón:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Si no recuerda su contraseña anterior le puede pedir a su administrador que recupere sus archivos.",
    "Old log-in password" : "Contraseña anterior",
    "Current log-in password" : "Contraseña actual",
    "Update Private Key Password" : "Actualizar Contraseña de Llave Privada",
    "Enable password recovery:" : "Habilitar la recuperación de contraseña:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar esta opción le permitirá volver a tener acceso a sus archivos encriptados en caso de perder la contraseña",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/es_AR.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Contraseña de llave de recuperacion faltante",
    "Please repeat the recovery key password" : "Favor de reingresar la contraseña de recuperación",
    "Repeated recovery key password does not match the provided recovery key password" : "Las contraseñas de la llave de recuperación no coinciden",
    "Recovery key successfully enabled" : "Llave de recuperación habilitada exitosamente",
    "Could not enable recovery key. Please check your recovery key password!" : "No fue posible habilitar la llave de recuperación. ¡Favor de comprobar la contraseña de su llave de recuperación!",
    "Recovery key successfully disabled" : "Llave de recuperación deshabilitada exitosamente",
    "Could not disable recovery key. Please check your recovery key password!" : "No fue posible deshabilitar la llave de recuperación. ¡Favor de comprobar la contraseña de la llave de recuperación!",
    "Missing parameters" : "Parámetros faltantes",
    "Please provide the old recovery password" : "Favor de proporcionar su contraseña de recuperación anterior",
    "Please provide a new recovery password" : "Favor de proporcionar una nueva contraseña de recuperación",
    "Please repeat the new recovery password" : "Favor de reingresar la nueva contraseña de recuperación",
    "Password successfully changed." : "La contraseña ha sido cambiada exitosamente",
    "Could not change the password. Maybe the old password was not correct." : "No fue posible cambiar la contraseña. Favor de verificar que contraseña anterior sea correcta.",
    "Recovery Key disabled" : "Llave de recuperación deshabilitada",
    "Recovery Key enabled" : "Llave de recuperación habilitada",
    "Could not enable the recovery key, please try again or contact your administrator" : "No fue posible habilitar la llave de recuperación, favor de intentarlo de nuevo o contacte a su administrador",
    "Could not update the private key password." : "No fue posible actualizar la contraseña de la llave privada.",
    "The old password was not correct, please try again." : "La contraseña anterior no es correcta, favor de intentar de nuevo. ",
    "The current log-in password was not correct, please try again." : "La contraseña actual para iniciar sesión fue incorrecta, favor de volverlo a intentar. ",
    "Private key password successfully updated." : "Contraseña de llave privada actualizada exitosamente.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "La llave de encriptación privada es inválida para la aplicación de encriptación. Favor de actualizar la contraseña de su llave privada en sus configuraciones personales para recuperar el acceso a sus archivos encriptados. ",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "La aplicación de encripción está habilitada, pero sus llaves no han sido inicializadas. Favor de cerrar sesión e iniciar sesión de nuevo. ",
    "Encryption app is enabled and ready" : "La aplicación de encripción se cuentra habilitada y lista",
    "Bad Signature" : "Firma equivocada",
    "Missing Signature" : "Firma faltante",
    "one-time password for server-side-encryption" : "Contraseña de una-sola-vez para la encripción del lado del servidor",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es posible decriptar este archivo, posiblemente sea un archivo compartido. Favor de solicitar al dueño del archivo que lo vuelva a compartir con usted.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "No es posible leer este archivo, posiblemente sea un archivo compatido. Favor de solicitar al dueño que vuelva a compartirlo con usted. ",
    "Default encryption module" : "Módulo de encripción predeterminado",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hola,\n\nel administrador ha habilitado la encripción de lado del servidor. Sus archivos fueron encriptados usando la contraseña '%s'\n\nFavor de iniciar sesión en la interface web, vaya a la sección \"módulo de encripción básica\" de sus configuraciones personales y actualice su contraseña de encripción ingresando esta contraseña en el campo 'contraseña de inicio de sesión anterior' y su contraseña de inicio de sesión actual. \n",
    "The share will expire on %s." : "El elemento compartido expirará el %s.",
    "Cheers!" : "¡Saludos!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hola, <br><br>el administrador ha habilitado la encripción del lado del servidor. Sus archivos fueron encriptados usando la contraseña <strong>%s</strong>.<br><br> Favor de iniciar sesisón en la interface web, vaya a la sección \"módulo de encripción básica\" de sus configuraciones personales y actualice su contraseña de encripción ingresando esta contraseña en el campo \"contraseña de inicio de sesión anterior\" y su contraseña de inicio de sesión actual. <br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "La aplicación de encripción esta habilitada pero sus llaves no han sido inicializadas, favor de salir y volver a entrar a la sesion",
    "Encrypt the home storage" : "Encriptar el almacenamiento de inicio",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Habilitar esta opción encripta todos los archivos almacenados en el almacenamiento principal, de otro modo, sólo los archivos en el almacenamiento externo serán encriptados",
    "Enable recovery key" : "Habilitar llave de recuperación",
    "Disable recovery key" : "Deshabilitar llave de recuperación",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "La llave de recuperación es una llave de encripción que se usa para encriptar archivos. Permite la recuperación de los archivos del usuario si este olvida su contraseña. ",
    "Recovery key password" : "Contraseña de llave de recuperación",
    "Repeat recovery key password" : "Repetir la contraseña de la llave de recuperación",
    "Change recovery key password:" : "Cambiar la contraseña de la llave de recuperación:",
    "Old recovery key password" : "Anterior contraseña de llave de recuperación",
    "New recovery key password" : "Nueva contraseña de llave de recuperación",
    "Repeat new recovery key password" : "Reingresar la nueva contraseña de llave de recuperación",
    "Change Password" : "Cambiar contraseña",
    "Basic encryption module" : "Módulo de encripción básica",
    "Your private key password no longer matches your log-in password." : "Su contraseña de llave privada ya no corresónde con su contraseña de inicio de sesión. ",
    "Set your old private key password to your current log-in password:" : "Establezca su contraseña de llave privada a su contraseña actual de inicio de seisón:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Si no recuerda su contraseña anterior le puede pedir a su administrador que recupere sus archivos.",
    "Old log-in password" : "Contraseña anterior",
    "Current log-in password" : "Contraseña actual",
    "Update Private Key Password" : "Actualizar Contraseña de Llave Privada",
    "Enable password recovery:" : "Habilitar la recuperación de contraseña:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Habilitar esta opción le permitirá volver a tener acceso a sus archivos encriptados en caso de perder la contraseña",
    "Enabled" : "Habilitado",
    "Disabled" : "Deshabilitado",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Usted necesita migrar sus llaves de la encripción anterior (ownCloud <=8.0) a la nueva. Favor de ejecutar 'occ encryption:migrate' o contacte a su adminstrador"
},
"nplurals=2; plural=(n != 1);");
